==> topia-persistence-2.2.1-sources.jar: org/nuiton/topia/generator/DAOGenerator.java <==
/* *##% ToPIA - Persistence
 * Copyright (C) 2004 - 2009 CodeLutin
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Lesser Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>. ##%*/

/* *
* EntityPOJOGenerator.java
*
* Created: 12 déc. 2005
*
* @author Arnaud Thimel <thimel@codelutin.com>
* @version $Revision: 1558 $
*
* Mise a jour: $Date: 2009-06-11 06:53:44 +0200 (jeu., 11 juin 2009) $
* par : $Author: tchemit $
*/

package org.nuiton.topia.generator;

import java.io.File;
import java.io.IOException;
import java.io.Writer;

import org.nuiton.eugene.Generator;
import org.nuiton.eugene.ObjectModelGenerator;
import org.nuiton.eugene.models.object.ObjectModelClass;

public class DAOGenerator extends ObjectModelGenerator {

    public DAOGenerator() {
        super();
    }

    public DAOGenerator(Generator parent) {
        super(parent);
    }

    @Override
    public String getFilenameForClass(ObjectModelClass clazz) {
        return clazz.getQualifiedName().replace('.', File.separatorChar) + "DAO.java";
    }

    @Override
    public void generateFromClass(Writer output, ObjectModelClass clazz) throws IOException {
        if (!clazz.hasStereotype(TopiaGeneratorUtil.STEREOTYPE_ENTITY)) {
            return;
        }
        String copyright = TopiaGeneratorUtil.getCopyright(model);
        if (TopiaGeneratorUtil.notEmpty(copyright)) {
output.write(""+copyright+"\n");
output.write("");
        }
        String clazzName = clazz.getName();
        String clazzFQN = clazz.getQualifiedName();
output.write("package "+clazz.getPackageName()+";\n");
output.write(" \n");
output.write("/**\n");
output.write(" * Cette classe etend le DAOImpl pour parametrer la classe avec le bon type\n");
output.write(" * Cette classe est marque finale car l'heritage entre les DAO se fait\n");
output.write(" * sur les DOAImpl, c-a-d que DAOAbstract peut etendre le DAOImpl\n");
output.write(" */\n");
output.write("public final class "+clazzName+"DAO extends "+clazzFQN+"DAOImpl<"+clazzName+">  {\n");
output.write("\n");
output.write("");

output.write("} //"+clazzName+"DAO\n");
output.write("");
    }

} //DAOGenerator

==> topia-persistence-2.3.1-sources.jar: org/nuiton/topia/generator/DAOGenerator.java <==
/* *##% 
 * ToPIA :: Persistence
 * Copyright (C) 2004 - 2009 CodeLutin
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Lesser Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * ##%*/

/*{generator option: parentheses = true}*/
/*{generator option: writeString = output.write}*/

/* *
* EntityPOJOGenerator.java
*
* Created: 12 déc. 2005
*
* @author Arnaud Thimel <thimel@codelutin.com>
* @version $Revision: 1732 $
*
* Mise a jour: $Date: 2009-12-20 17:29:38 +0100 (dim. 20 déc. 2009) $
* par : $Author: tchemit $
*/

package org.nuiton.topia.generator;

import java.io.File;
import java.io.IOException;
import java.io.Writer;

import org.nuiton.eugene.models.object.ObjectModelGenerator;
import org.nuiton.eugene.models.object.ObjectModelClass;

/**
 *
 * @deprecated since 2.3.0, prefer use the corresponding {@link org.nuiton.eugene.Transformer} :
 * {@link DAOTransformer}.
 * @plexus.component role="org.nuiton.eugene.Template" role-hint="org.nuiton.topia.generator.DAOGenerator"
 */
@Deprecated
public class DAOGenerator extends ObjectModelGenerator {


    @Override
    public String getFilenameForClass(ObjectModelClass clazz) {
        return clazz.getQualifiedName().replace('.', File.separatorChar) + "DAO.java";
    }

    @Override
    public void generateFromClass(Writer output, ObjectModelClass clazz) throws IOException {
        if (!clazz.hasStereotype(TopiaGeneratorUtil.STEREOTYPE_ENTITY)) {
            return;
        }
        String copyright = TopiaGeneratorUtil.getCopyright(model);
        if (TopiaGeneratorUtil.notEmpty(copyright)) {
/*{<%=copyright%>
}*/
        }
        String clazzName = clazz.getName();
        String clazzFQN = clazz.getQualifiedName();
/*{package <%=clazz.getPackageName()%>;
 
/**
 * Cette classe etend le DAOImpl pour parametrer la classe avec le bon type
 * Cette classe est marque finale car l'heritage entre les DAO se fait
 * sur les DOAImpl, c-a-d que DAOAbstract peut etendre le DAOImpl
 *)
public final class <%=clazzName%>DAO extends <%=clazzFQN%>DAOImpl<<%=clazzName%>>  {

}*/

/*{} //<%=clazzName%>DAO
}*/
    }

} //DAOGenerator
